ScannerController class final

Used by ScannerPreview.

Constructors

ScannerController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAttached ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAttached(FlutterDocsScanner scanner, CameraController controller) → void
Should not be called outside of ScannerPreview.
takeAndProcess() → Future<MemoryImage>
Takes shot and returns processed image of recognized document.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited